#ifndef PyObjC_WEAKREF_H
#define PyObjC_WEAKREF_H

NS_ASSUME_NONNULL_BEGIN

extern PyTypeObject PyObjCWeakRef_Type;

NS_ASSUME_NONNULL_END

#endif /* PyObjC_WEAKREF_H */
